aboutsummaryrefslogtreecommitdiff
path: root/zenserver/config.h
diff options
context:
space:
mode:
authorStefan Boberg <[email protected]>2021-09-17 19:11:11 +0200
committerStefan Boberg <[email protected]>2021-09-17 19:11:11 +0200
commit03dddb20a2a378eaf8c529a986ccfaeb8ee019a7 (patch)
tree2aa5ee04c38ae5a69acf2558e736e9eb785c2284 /zenserver/config.h
parentAdded UNICODE and defined _WIN32_WINNT to match the sln (diff)
downloadzen-03dddb20a2a378eaf8c529a986ccfaeb8ee019a7.tar.xz
zen-03dddb20a2a378eaf8c529a986ccfaeb8ee019a7.zip
Implemented basics for Windows server support (not yet 100% - needs to properly report service state etc to the OS)
Diffstat (limited to 'zenserver/config.h')
-rw-r--r--zenserver/config.h14
1 files changed, 8 insertions, 6 deletions
diff --git a/zenserver/config.h b/zenserver/config.h
index 80ec86905..c06102384 100644
--- a/zenserver/config.h
+++ b/zenserver/config.h
@@ -9,12 +9,14 @@ struct ZenServerOptions
{
bool IsDebug = false;
bool IsTest = false;
- bool IsDedicated = false; // Indicates a dedicated/shared instance, with larger resource requirements
- int BasePort = 1337; // Service listen port (used for both UDP and TCP)
- int OwnerPid = 0; // Parent process id (zero for standalone)
- std::string ChildId; // Id assigned by parent process (used for lifetime management)
- std::string LogId; // Id for tagging log output
- std::filesystem::path DataDir; // Root directory for state (used for testing)
+ bool IsDedicated = false; // Indicates a dedicated/shared instance, with larger resource requirements
+ int BasePort = 1337; // Service listen port (used for both UDP and TCP)
+ int OwnerPid = 0; // Parent process id (zero for standalone)
+ std::string ChildId; // Id assigned by parent process (used for lifetime management)
+ bool InstallService = false; // Flag used to initiate service install (temporary)
+ bool UninstallService = false; // Flag used to initiate service uninstall (temporary)
+ std::string LogId; // Id for tagging log output
+ std::filesystem::path DataDir; // Root directory for state (used for testing)
};
struct ZenUpstreamJupiterConfig